diff default_options.h @ 1634:aabde6f57fce

Add a sanity check for DROPBEAR_SVR_MULTIUSER==0 mode
author Matt Johnston <matt@ucc.asn.au>
date Wed, 20 Mar 2019 22:57:06 +0800
parents 592a18dac250
children a2bbc22ea1e6 d32bcb5c557d
line wrap: on
line diff
--- a/default_options.h	Wed Mar 20 14:44:49 2019 +0000
+++ b/default_options.h	Wed Mar 20 22:57:06 2019 +0800
@@ -196,7 +196,9 @@
  * authorized_keys file into account */
 #define DROPBEAR_SVR_PUBKEY_OPTIONS 1
 
-/* Disable if your kernel does not have multiple user support */
+/* Set this to 0 if your system does not have multiple user support.
+   (Linux kernel CONFIG_MULTIUSER option)
+   The resulting binary will not run on a normal system. */
 #define DROPBEAR_SVR_MULTIUSER 1
 
 /* Client authentication options */